# Generated by Django 5.2.3 on 2025-07-01 15:54

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_expiringtoken'),
    ]

    operations = [
        migrations.AddField(
            model_name='apikey',
            name='shard_id',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='expiringtoken',
            name='token_id',
            field=models.UUIDField(blank=True, default=uuid.uuid4, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='expiringtoken',
            name='key',
            field=models.CharField(max_length=64, primary_key=True, serialize=False),
        ),
    ]
