# Generated by Django 5.2.3 on 2025-07-29 05:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0008_delete_expiringtoken'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='apikey',
            name='shard_id',
        ),
    ]
