# Generated by Django 5.2.3 on 2025-08-07 21:48

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0010_apiusagelog_useractivitylog'),
        ('simulator', '0004_simulatorlog_confidence_simulatorlog_prompt'),
    ]

    operations = [
        migrations.AddField(
            model_name='simulationrun',
            name='api_key',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='api.apikey'),
        ),
    ]
